@@ -1,6 +1,6 @@
 import numpy as np
 
-from plum.util import multihash, Comparable, get_default
+from plum.util import multihash, Comparable, is_in_class, get_class, get_context
 
 
 def test_multihash():
@@ -30,8 +30,29 @@ def test_comparable():
     assert not Number(1).is_comparable(Number(np.nan))
 
 
-def test_get_default():
-    d = {'key': 'value'}
+class A:
+    def f(self):
+        pass
 
-    assert get_default(d, 'key', 1) == 'value'
-    assert get_default(d, 'key2', 1) == 1
+
+def f(self):
+    pass
+
+
+def test_is_in_class():
+    assert is_in_class(A.f)
+    assert is_in_class(A().f)
+    assert not is_in_class(f)
+    assert not is_in_class(lambda _: None)
+
+
+def test_get_class():
+    assert get_class(A.f) == "tests.test_util.A"
+    assert get_class(A().f) == "tests.test_util.A"
+
+
+def test_get_context():
+    assert get_context(A.f) == "tests.test_util"
+    assert get_context(A().f) == "tests.test_util"
+    assert get_context(f) == "tests.test_util"
+    assert get_context(lambda _: None) == "tests.test_util.test_get_context.<locals>"
